﻿using Microsoft.AspNetCore.DataProtection;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.RazorPages;
using System.Security.Cryptography;

namespace CookieDemo.Pages
{
    public class IndexModel : PageModel
    {
        private readonly ILogger<IndexModel> _logger;
        private readonly IDataProtectionProvider dataProtectionProvider;

        [BindProperty]
        public string? MyProperty { get; set; }

        public IndexModel(ILogger<IndexModel> logger, IDataProtectionProvider dataProtectionProvider)
        {
            _logger = logger;
            this.dataProtectionProvider = dataProtectionProvider;
        }

        public void OnGet()
        {
            var value = this.Request.Cookies["MyPropertySecure"];
            if (!string.IsNullOrEmpty(value))
            {
                var protector = this.dataProtectionProvider.CreateProtector("CookieProtection");
                try
                {
                    this.MyProperty = protector.Unprotect(value);
                }
                catch (CryptographicException)
                {
                    this.MyProperty = string.Empty;
                }
            }
        }

        public IActionResult OnPost()
        {
            var protector = this.dataProtectionProvider.CreateProtector("CookieProtection");
            var protectedValue = protector.Protect(this.MyProperty);

            this.Response.Cookies.Append("MyPropertySecure", protectedValue, new CookieOptions
            {
                MaxAge = TimeSpan.FromDays(365),
            }); ;
            return this.RedirectToPage();
        }
    }
}